==> zio-aws-sagemaker_3-5.17.127.2-sources.jar: zio/aws/sagemaker/model/GetSagemakerServicecatalogPortfolioStatusResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetSagemakerServicecatalogPortfolioStatusResponse(
    status: Option[zio.aws.sagemaker.model.SagemakerServicecatalogStatus] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse = {
    import GetSagemakerServicecatalogPortfolioStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
      .builder()
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse.ReadOnly =
    zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
      .wrap(buildAwsValue())
}
object GetSagemakerServicecatalogPortfolioStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse =
      zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse(
        status.map(value => value)
      )
    def status: Option[zio.aws.sagemaker.model.SagemakerServicecatalogStatus]
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.SagemakerServicecatalogStatus
    ] = AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
  ) extends zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse.ReadOnly {
    override val status
        : Option[zio.aws.sagemaker.model.SagemakerServicecatalogStatus] = scala
      .Option(impl.status())
      .map(value =>
        zio.aws.sagemaker.model.SagemakerServicecatalogStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
  ): zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemaker_3-5.17.295.5-sources.jar: zio/aws/sagemaker/model/GetSagemakerServicecatalogPortfolioStatusResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetSagemakerServicecatalogPortfolioStatusResponse(
    status: Optional[zio.aws.sagemaker.model.SagemakerServicecatalogStatus] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse = {
    import GetSagemakerServicecatalogPortfolioStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
      .builder()
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse.ReadOnly =
    zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
      .wrap(buildAwsValue())
}
object GetSagemakerServicecatalogPortfolioStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse =
      zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse(
        status.map(value => value)
      )
    def status: Optional[zio.aws.sagemaker.model.SagemakerServicecatalogStatus]
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.SagemakerServicecatalogStatus
    ] = AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
  ) extends zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse.ReadOnly {
    override val status
        : Optional[zio.aws.sagemaker.model.SagemakerServicecatalogStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.sagemaker.model.SagemakerServicecatalogStatus.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse
  ): zio.aws.sagemaker.model.GetSagemakerServicecatalogPortfolioStatusResponse.ReadOnly =
    new Wrapper(impl)
}
